# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic import BaseModel, Field, StrictInt, conlist
from chat_server_connector.models.usage_data_v2 import UsageDataV2

class UsageDataFromFrontV2(BaseModel):
    """
    UsageDataFromFrontV2
    """
    chat_session_id: StrictInt = Field(...)
    usage_data: conlist(UsageDataV2) = Field(...)
    __properties = ["chat_session_id", "usage_data"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> UsageDataFromFrontV2:
        """Create an instance of UsageDataFromFrontV2 from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in usage_data (list)
        _items = []
        if self.usage_data:
            for _item in self.usage_data:
                if _item:
                    _items.append(_item.to_dict())
            _dict['usage_data'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> UsageDataFromFrontV2:
        """Create an instance of UsageDataFromFrontV2 from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return UsageDataFromFrontV2.parse_obj(obj)

        _obj = UsageDataFromFrontV2.parse_obj({
            "chat_session_id": obj.get("chat_session_id"),
            "usage_data": [UsageDataV2.from_dict(_item) for _item in obj.get("usage_data")] if obj.get("usage_data") is not None else None
        })
        return _obj


